==> xlniuxdata-vipgame-1.0.32-20151028.071625-7-sources.jar: com/xunlei/niux/data/vipgame/dto/BonusChargeRecordDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

public class BonusChargeRecordDTO {
	private Long seqId;
	private Long userId;		//迅雷uid
	private String userName;	//迅雷账号
	private String giftId;	//商品id
	private String giftName;	//商品名称
	private String giftType;	//商品类型
	private Integer isValid;//商品状态
	private Long bonus;			//所需积分
	private String recordTime;	//兑换时间
	private String ip;			//ip
	private Integer chargeFlag;	//发货状态
	
	private Long minBonus;
	private Long MaxBonus;
	
	private String startTime;
	private String endTime;
	
	
	
	
	
	//private Integer activationCode;	//激活码
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getGiftId() {
		return giftId;
	}
	public void setGiftId(String giftId) {
		this.giftId = giftId;
	}
	public String getGiftName() {
		return giftName;
	}
	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}
	public String getGiftType() {
		return giftType;
	}
	public void setGiftType(String giftType) {
		this.giftType = giftType;
	}
	public Integer getIsValid() {
		return isValid;
	}
	public void setIsValid(Integer isValid) {
		this.isValid = isValid;
	}
	public Long getBonus() {
		return bonus;
	}
	public void setBonus(Long bonus) {
		this.bonus = bonus;
	}
	public String getRecordTime() {
		return recordTime;
	}
	public void setRecordTime(String recordTime) {
		this.recordTime = recordTime;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public Integer getChargeFlag() {
		return chargeFlag;
	}
	public void setChargeFlag(Integer chargeFlag) {
		this.chargeFlag = chargeFlag;
	}
	public Long getMinBonus() {
		return minBonus;
	}
	public void setMinBonus(Long minBonus) {
		this.minBonus = minBonus;
	}
	public Long getMaxBonus() {
		return MaxBonus;
	}
	public void setMaxBonus(Long maxBonus) {
		MaxBonus = maxBonus;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}
	
	
	
	
	
	
	

}

==> xlniuxdata-vipgame-1.0.106-sources.jar: com/xunlei/niux/data/vipgame/dto/BonusChargeRecordDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

public class BonusChargeRecordDTO {
	private Long seqId;
	private Long userId;		//迅雷uid
	private String userName;	//迅雷账号
	private String giftId;	//商品id
	private String giftName;	//商品名称
	private String giftType;	//商品类型
	private Integer isValid;//商品状态
	private Long bonus;			//所需积分
	private String recordTime;	//兑换时间
	private String ip;			//ip
	private Integer chargeFlag;	//发货状态
	
	private Long minBonus;
	private Long MaxBonus;
	
	private String startTime;
	private String endTime;

	private Boolean isBox;

	public Boolean getIsBox() {
		return isBox;
	}

	public void setIsBox(Boolean isBox) {
		this.isBox = isBox;
	}

	//private Integer activationCode;	//激活码
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public Long getUserId() {
		return userId;
	}
	public void setUserId(Long userId) {
		this.userId = userId;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getGiftId() {
		return giftId;
	}
	public void setGiftId(String giftId) {
		this.giftId = giftId;
	}
	public String getGiftName() {
		return giftName;
	}
	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}
	public String getGiftType() {
		return giftType;
	}
	public void setGiftType(String giftType) {
		this.giftType = giftType;
	}
	public Integer getIsValid() {
		return isValid;
	}
	public void setIsValid(Integer isValid) {
		this.isValid = isValid;
	}
	public Long getBonus() {
		return bonus;
	}
	public void setBonus(Long bonus) {
		this.bonus = bonus;
	}
	public String getRecordTime() {
		return recordTime;
	}
	public void setRecordTime(String recordTime) {
		this.recordTime = recordTime;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public Integer getChargeFlag() {
		return chargeFlag;
	}
	public void setChargeFlag(Integer chargeFlag) {
		this.chargeFlag = chargeFlag;
	}
	public Long getMinBonus() {
		return minBonus;
	}
	public void setMinBonus(Long minBonus) {
		this.minBonus = minBonus;
	}
	public Long getMaxBonus() {
		return MaxBonus;
	}
	public void setMaxBonus(Long maxBonus) {
		MaxBonus = maxBonus;
	}
	public String getStartTime() {
		return startTime;
	}
	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}
	public String getEndTime() {
		return endTime;
	}
	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}
	
	
	
	
	
	
	

}
